
#ifndef _C15_re713_
#define _C15_re713_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_INTEGER_32 F698_4128(EIF_REFERENCE);
extern void F698_4130(EIF_REFERENCE);
extern void EIF_Minit713(void);
extern char *(*R3567[])();
extern char *(*R3573[])();

#ifdef __cplusplus
}
#endif

#endif
